package com.nisum.poc.api.department.controller;

import com.nisum.poc.api.department.dto.DepartmentDetailDto;
import com.nisum.poc.api.department.entity.Department;
import com.nisum.poc.api.department.request.DepartmentDetailRequest;
import com.nisum.poc.api.department.response.DepartmentDetailResponse;
import com.nisum.poc.api.department.service.IDepartmentService;
import org.modelmapper.ModelMapper;
import org.modelmapper.convention.MatchingStrategies;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping(value = "/department")
public class DepartmentController {

    Logger logger = LoggerFactory.getLogger(DepartmentController.class);
    private IDepartmentService departmentService;

    @Autowired
    public DepartmentController(IDepartmentService departmentService){
        this.departmentService = departmentService;
    }

    @PostMapping(value = "/v1/create")
    public Mono<Department> createDepartment(@RequestBody DepartmentDetailRequest departmentDetailRequest){
        return departmentService.createDepartment(serviceDtoConvertor(departmentDetailRequest));
    }

    @GetMapping("/v1/find/{departmentId}")
    public Mono<Department> fetchDepartmentById(@PathVariable Long departmentId){

        logger.info("Request Received to Find Dept  : {}", departmentId);
        return departmentService.findDepartmentById(departmentId);
    }


    private DepartmentDetailDto serviceDtoConvertor(DepartmentDetailRequest departmentDetailRequest){

        ModelMapper modelMapper = new ModelMapper();
        modelMapper.getConfiguration().setMatchingStrategy(MatchingStrategies.STRICT);
        return  modelMapper.map(departmentDetailRequest, DepartmentDetailDto.class);
    }
}
