package com.nisum.poc.api.department.service.impl;

import com.nisum.poc.api.department.data.DepartmentRepository;
import com.nisum.poc.api.department.dto.DepartmentDetailDto;
import com.nisum.poc.api.department.entity.Department;
import com.nisum.poc.api.department.request.DepartmentDetailRequest;
import com.nisum.poc.api.department.response.DepartmentDetailResponse;
import com.nisum.poc.api.department.service.IDepartmentService;
import org.modelmapper.ModelMapper;
import org.modelmapper.convention.MatchingStrategies;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

@Service
public class DepartmentService implements IDepartmentService {

    private DepartmentRepository departmentRepository;

    @Autowired
    public DepartmentService(DepartmentRepository departmentRepository) {
        this.departmentRepository = departmentRepository;
    }

    @Override
    public Mono<Department> createDepartment(DepartmentDetailDto departmentDetailDto) {
        return departmentRepository.insert(serviceDtoConvertor(departmentDetailDto));
    }

    @Override
    public Mono<Department> findDepartmentById(Long departmentId) {
        return departmentRepository.findById(departmentId);
    }


    private Department serviceDtoConvertor(DepartmentDetailDto departmentDetailDto){

        ModelMapper modelMapper = new ModelMapper();
        modelMapper.getConfiguration().setMatchingStrategy(MatchingStrategies.STRICT);
        return  modelMapper.map(departmentDetailDto, Department.class);
    }
}
